@@ -2,7 +2,7 @@
 
 /* otf.{cc,hh} -- OpenType font basics
  *
- * Copyright (c) 2002-2006 Eddie Kohler
+ * Copyright (c) 2002-2011 Eddie Kohler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -132,6 +132,15 @@ Font::table(Tag tag) const
 	return String();
 }
 
+bool
+Font::has_table(Tag tag) const
+{
+    const uint8_t *entry = 0;
+    if (error() >= 0)
+	entry = tag.table_entry(data() + HEADER_SIZE, USHORT_AT(data() + 4), TABLE_DIR_ENTRY_SIZE);
+    return entry != 0;
+}
+
 uint32_t
 Font::table_checksum(Tag tag) const
 {
